precision mediump float;
varying vec2 vTextureCoord;
uniform sampler2D uTexture;

uniform sampler2D uLastTexture;
varying vec2 vLastTextureCoord;

uniform float thresholdSensitivity;
uniform float smoothing;
uniform vec3 colorToReplace;


vec3 RGB2HSV(vec3 rgb){

        float R=rgb.x;
        float G=rgb.y;
        float B=rgb.z;

        float h;
        float s;
        float v;
        float max1=max(R,max(G,B));
        float min1=min(R,min(G,B));

        if(R==max1){
            h=(G-B)/(max1-min1);
        }
        if(G==max1){
            h=2.0+(B-R)/(max1-min1);
        }
        if(B==max1){
            h=4.0+(R-G)/(max1-min1);
        }
        h=h*60.0;
        if(h<0.0){
            h=h+360.0;
        }
        v=max1;
        s=(max1-min1)/max1;
        return vec3(h,s,v);

}

vec3 HSV2RGB(vec3 hsv){

        float R;
        float G;
        float B;
        if(hsv.y==0.0){
            R=G=B=hsv.z;
        }else{
            hsv.x=hsv.x/60.0;
//            int i=int(hsv.x);
            int i=int(hsv.x-6.0*floor(hsv.x/6.0));
            float f=hsv.x-float(i);
            float a=hsv.z*(1.0-hsv.y);
            float b=hsv.z*(1.0-hsv.y*f);
            float c=hsv.z*(1.0-hsv.y*(1.0-f));


            if(i==0){
                R=hsv.z;
                G=c;
                B=a;
            }else if(i==1){
                R=b;
                G=hsv.z;
                B=a;
            }else if(i==2){
                R=a;
                G=hsv.z;
                B=c;
            }else if(i==3){
                R=a;
                G=b;
                B=hsv.z;
            }else if(i==4){
                R=c;
                G=a;
                B=hsv.z;
            }else if(i==5){
                R=hsv.z;
                G=a;
                B=b;
            }
        }

        return vec3(R,G,B);
}


void main() {

   vec4 overlayColor=texture2D(uTexture,vTextureCoord);

   vec4 lastColor=texture2D(uLastTexture,vLastTextureCoord);

//   vec3 overlayHSV=RGB2HSV(overlayColor.rgb);
//   vec3 lastHSV=RGB2HSV(lastColor.rgb);

//   float alpha;
//   if(overlayHSV.x>=85.0 && overlayHSV.x<=155.0){
//        alpha=0.0;
//   }else{
//        alpha=1.0;
//   }
//   if(overlayHSV.y<0.2){
//        alpha=1.0;
//   }
//   if(overlayHSV.z<0.2){
//        alpha=1.0;
//   }

     float maskY = 0.2989 * overlayColor.r + 0.5866 * overlayColor.g + 0.1145 * overlayColor.b;
     float maskCr = 0.7132 * (overlayColor.r - maskY);
     float maskCb = 0.5647 * (overlayColor.b - maskY);

      float Y = 0.2989 * colorToReplace.r + 0.5866 * colorToReplace.g + 0.1145 * colorToReplace.b;
      float Cr = 0.7132 * (colorToReplace.r - Y);
      float Cb = 0.5647 * (colorToReplace.b - Y);


    float blendValue = smoothstep(thresholdSensitivity, thresholdSensitivity + smoothing, distance(vec2(Cr, Cb), vec2(maskCr, maskCb)));

   gl_FragColor=vec4(mix(lastColor.rgb,overlayColor.rgb,lastColor.a*blendValue),1.0);
}
